@@ -3,25 +3,17 @@
 # This program is licensed under the Apache License version 2.
 # See LICENSE or go to <https://www.apache.org/licenses/LICENSE-2.0.txt> for full license details.
 
-import numpy as np
+from typing import List, Tuple
+
 import cv2
-from typing import List, Any, Optional, Dict, Tuple
+import numpy as np
 
-from doctr.utils.repr import NestedObject
 from doctr.utils.geometry import rotate_image
+from doctr.utils.repr import NestedObject
+
 from .._utils import get_bitmap_angle
-from .. import PreProcessor
 
-
-__all__ = ['DetectionModel', 'DetectionPostProcessor', 'DetectionPredictor']
-
-
-class DetectionModel(NestedObject):
-    """Implements abstract DetectionModel class"""
-
-    def __init__(self, cfg: Optional[Dict[str, Any]] = None) -> None:
-        super().__init__()
-        self.cfg = cfg
+__all__ = ['DetectionPostProcessor']
 
 
 class DetectionPostProcessor(NestedObject):
@@ -106,7 +98,7 @@ class DetectionPostProcessor(NestedObject):
 
         for p_, bitmap_ in zip(proba_map, bitmap):
             # Perform opening (erosion + dilatation)
-            bitmap_ = cv2.morphologyEx(bitmap_, cv2.MORPH_OPEN, kernel)
+            bitmap_ = cv2.morphologyEx(bitmap_.astype(np.float32), cv2.MORPH_OPEN, kernel)
             # Rotate bitmap and proba_map
             angle = get_bitmap_angle(bitmap_)
             angles_batch.append(angle)
@@ -115,40 +107,3 @@ class DetectionPostProcessor(NestedObject):
             boxes_batch.append(boxes)
 
         return boxes_batch, angles_batch
-
-
-class DetectionPredictor(NestedObject):
-    """Implements an object able to localize text elements in a document
-
-    Args:
-        pre_processor: transform inputs for easier batched model inference
-        model: core detection architecture
-    """
-
-    _children_names: List[str] = ['pre_processor', 'model']
-
-    def __init__(
-        self,
-        pre_processor: PreProcessor,
-        model: DetectionModel,
-    ) -> None:
-
-        self.pre_processor = pre_processor
-        self.model = model
-
-    def __call__(
-        self,
-        pages: List[np.ndarray],
-        **kwargs: Any,
-    ) -> List[np.ndarray]:
-
-        # Dimension check
-        if any(page.ndim != 3 for page in pages):
-            raise ValueError("incorrect input shape: all pages are expected to be multi-channel 2D images.")
-
-        processed_batches = self.pre_processor(pages)
-        predicted_batches = [
-            self.model(batch, return_boxes=True, **kwargs)['preds']  # type:ignore[operator]
-            for batch in processed_batches
-        ]
-        return [pred for batch in predicted_batches for pred in zip(*batch)]
