@@ -5,14 +5,16 @@
 
 # Credits: post-processing adapted from https://github.com/xuannianz/DifferentiableBinarization
 
+from typing import List, Optional, Tuple, Union
+
 import cv2
 import numpy as np
-from shapely.geometry import Polygon
 import pyclipper
-from typing import Union, List, Tuple, Optional
+from shapely.geometry import Polygon
 
-from doctr.utils.geometry import fit_rbbox, rbbox_to_polygon
 from doctr.utils.common_types import RotatedBbox
+from doctr.utils.geometry import fit_rbbox, rbbox_to_polygon
+
 from ..core import DetectionPostProcessor
 
 __all__ = ['DBPostProcessor']
@@ -254,8 +256,8 @@ class _DBNet:
         output_shape: Tuple[int, int, int],
     ) -> Tuple[np.ndarray, np.ndarray, np.ndarray, np.ndarray]:
 
-        if any(t.dtype not in (np.float32, np.float16) for t in target):
-            raise AssertionError("the expected dtype of target 'boxes' entry is either 'np.float32' or 'np.float16'.")
+        if any(t.dtype != np.float32 for t in target):
+            raise AssertionError("the expected dtype of target 'boxes' entry is 'np.float32'.")
         if any(np.any((t[:, :4] > 1) | (t[:, :4] < 0)) for t in target):
             raise ValueError("the 'boxes' entry of the target is expected to take values between 0 & 1.")
 
