@@ -1,4 +1,4 @@
-from .core import *
 from .crnn import *
+from .master import *
 from .sar import *
 from .zoo import *
